@@ -14,11 +14,11 @@ import time
 
 import colorama
 
-from conjuguer.aux import aux
-from conjuguer.blank import blank_verb
+from .verbs import aux, etre_aux, both_aux
+from .blank import blank_verb
 
 # Version string used by the what(1) and ident(1) commands:
-ID = "@(#) $Id: conjuguer - conjugaison des verbes Français v0.1.1 (September 1, 2021) by Hubert Tournier $"
+ID = "@(#) $Id: conjuguer - conjugaison des verbes Français v0.2.0 (September 11, 2021) by Hubert Tournier $"
 
 # Default parameters. Can be overcome by environment variables, then command line options
 parameters = {
@@ -30,6 +30,7 @@ parameters = {
 }
 
 # Display constants:
+VERB_COLOR = colorama.Fore.WHITE + colorama.Style.BRIGHT
 MODE_CAPS=True
 MODE_COLOR = colorama.Fore.GREEN + colorama.Style.BRIGHT
 MODE_SEPARATOR="═"
@@ -40,8 +41,9 @@ BLANK_LINES=True
 COLUMN_SPACES = "    "
 
 # Default dictionaries:
-ABU = "dict-fr-ABU-mots_communs"
+AU_DELA = "dict-fr-AU-DELA"
 DELA = "dict-fr-DELA"
+ABU = "dict-fr-ABU-mots_communs"
 
 
 ################################################################################
@@ -125,6 +127,9 @@ def process_environment_variables():
     # Setting the default dictionary, if any:
     # (the first one named words)
     for directory in parameters["DictPath"]:
+        if os.path.isfile(directory + os.sep + AU_DELA):
+            parameters["Dictionary path"] = directory + os.sep + AU_DELA
+            break
         if os.path.isfile(directory + os.sep + DELA):
             parameters["Dictionary path"] = directory + os.sep + DELA
             break
@@ -232,6 +237,8 @@ def load_all_verbs_from_dictionary():
             for line in file.readlines():
                 line = line.strip()
                 if ".V" in line:
+                    # Unescape "-", "," and "." characters:
+                    line = line.replace("\\", "")
                     verbs.append(line)
         elif parameters["Dictionary type"] == "ABU":
             for line in file.readlines():
@@ -461,15 +468,28 @@ def fill_verb_from_abu_dictionary_data(verb, conjugations, auxiliary):
 
 ################################################################################
 # conjuguer = conjugate in French
-def conjuguer(verb, conjugations):
+def conjuguer(verb, conjugations, auxiliary):
     """Conjugation wrapper to do the (future) dirty work..."""
     if parameters["Dictionary type"] == "DELA":
-        conjugated_verb = fill_verb_from_dela_dictionary_data(verb, conjugations, "avoir")
+        conjugated_verb = fill_verb_from_dela_dictionary_data(verb, conjugations, auxiliary)
     elif parameters["Dictionary type"] == "ABU":
-        conjugated_verb = fill_verb_from_abu_dictionary_data(verb, conjugations, "avoir")
+        conjugated_verb = fill_verb_from_abu_dictionary_data(verb, conjugations, auxiliary)
     return conjugated_verb
 
 
+################################################################################
+def print_verb(verb):
+    """Return lines describing the conjugated verb"""
+    lines = []
+    if parameters["Color display"]:
+        lines.append(VERB_COLOR + "Tableau de conjugaison du verbe " + colorama.Style.RESET_ALL + verb)
+    else:
+        lines.append("Tableau de conjugaison du verbe " + verb)
+    lines.append("")
+
+    return lines
+
+
 ################################################################################
 def print_mode(mode):
     """Return lines describing the conjugation mode"""
@@ -620,6 +640,8 @@ def get_tense_conjugation(mode, tense, conjugation):
 def print_verb_conjugation_odd_columns(conjugation):
     """Print a 1 column verb conjugation"""
     column = []
+    column += print_verb(conjugation["Infinitif"]["Présent"])
+
     column += print_mode("Indicatif")
     for tense in ["Présent", "Imparfait", "Passé simple", "Futur simple", "Passé composé", "Plus-que-parfait", "Passé antérieur", "Futur antérieur"]:
         column += get_tense_conjugation("Indicatif", tense, conjugation)
@@ -726,6 +748,8 @@ def print_verb_conjugation_even_columns(conjugation):
         text += COLUMN_SPACES + column_4[i]
         column_34.append(text)
 
+    for line in print_verb(conjugation["Infinitif"]["Présent"]):
+        print(line)
     if parameters["Display columns"] == 2:
         for line in column_12 + column_34:
             print(line)
@@ -777,8 +801,17 @@ def main():
     for argument in arguments:
         conjugations = select_verb_from_verbs(argument, verbs)
         if conjugations:
-            verb = conjuguer(argument, conjugations)
-            print_verb_conjugation(verb)
+            if argument in etre_aux:
+                verb = conjuguer(argument, conjugations, "être")
+                print_verb_conjugation(verb)
+            elif argument in both_aux:
+                verb1 = conjuguer(argument, conjugations, "être")
+                print_verb_conjugation(verb1)
+                verb2 = conjuguer(argument, conjugations, "avoir")
+                print_verb_conjugation(verb2)
+            else:
+                verb = conjuguer(argument, conjugations, "avoir")
+                print_verb_conjugation(verb)
         else:
             logging.error("%s is not in the dictionary used", argument)
             exit_status = 1
